import { axios } from '@/utils/request'
import { stringify } from 'qs'

/**
 * page func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function getRemoteOpcPage (parameter) {
  return axios({
    url: '/remote/opcs/page?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * add func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function addRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs',
    method: 'POST',
    headers: {
      'Accept': 'application/json',
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data: parameter
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function updateRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs/' + parameter.id,
    method: 'PUT',
    data: parameter
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function addToServerRemoteOpcs (parameter) {
  return axios({
    url: '/remote/opcs/group/addAll',
    method: 'PUT',
    data: parameter
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function addRemoteOpcGroup (parameter) {
  return axios({
    url: '/remote/opcs/group/add/' + parameter,
    method: 'PUT'
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function delRemoteOpcGroup (parameter) {
  return axios({
    url: '/remote/opcs/group/del/' + parameter,
    method: 'PUT'
  })
}

/**
 * fetch single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function fetchRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs/' + parameter.id,
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * fetch single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function fetchRemoteOpcByPositionNumAndLine (parameter) {
  return axios({
    url: '/remote/opcs/positionNum/' + parameter.positionNum + '/' + parameter.line,
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * query list func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function queryRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * query list func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function queryRemoteOpcFromRedis (parameter) {
  return axios({
    url: '/remote/opcs/redis?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    }
  })
}

/**
 * update func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function updateRemoteOpcs (parameter) {
  return axios({
    url: '/remote/opcs/update/batch/' + parameter.updateType + '/' + parameter.value,
    method: 'PUT',
    data: parameter.ids
  })
}

/**
 * delete batch func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function deleteRemoteOpcs (parameter) {
  return axios({
    url: '/remote/opcs',
    method: 'DELETE',
    data: parameter
  })
}

/**
 * delete single func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function deleteRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs/' + parameter.id,
    method: 'DELETE',
    data: parameter
  })
}

/**
 * export file
 * parameter: { }
 * @param parameter :
  * @returns {*}
 */
export function exportRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs/export?' + stringify(parameter),
    method: 'get',
    headers: {
      'Content-Type': 'application/json;charset=UTF-8'
    },
    responseType: 'blob'
  })
}

/**
 * add batch func
 * parameter: { }
 * @param parameter
 * @returns {*}
 */
export function importRemoteOpc (parameter) {
  return axios({
    url: '/remote/opcs/import/' + parameter.line,
    method: 'POST',
    headers: {
      'Accept': 'application/json',
      'Content-Type': 'application/json;charset=UTF-8'
    },
    data: parameter
  })
}
