import Vue from 'vue'
import router from './router'
import store from './store'

import NProgress from 'nprogress' // progress bar
import '@/components/NProgress/nprogress.less' // progress bar custom style
import notification from 'ant-design-vue/es/notification'
import { setDocumentTitle, domTitle } from '@/utils/domUtil'
import { ACCESS_TOKEN } from '@/store/mutation-types'
import BaseTool from '@/utils/tool'
import { GlobalConstant } from '@/constant'

NProgress.configure({ showSpinner: false }) // NProgress Configuration

const whiteList = ['login', 'register', 'test', 'registerResult', GlobalConstant.SINGLE_LOGIN_ROUTER_NAME] // no redirect whitelist

router.beforeEach((to, from, next) => {
  if (to.path === GlobalConstant.PC_INDEX_PATH) {
    if (BaseTool.Util._isMobile()) {
      next({ path: GlobalConstant.MOBILE_INDEX_PATH, query: { } })
      NProgress.done()
      return
    }
  }
  // 单点登录
  if (to.name === GlobalConstant.SINGLE_LOGIN_ROUTER_NAME) {
    next()
    return
  }
  NProgress.start() // start progress bar
  to.meta && (typeof to.meta.title !== 'undefined' && setDocumentTitle(`${to.meta.title} - ${domTitle}`))
  if (Vue.ls.get(ACCESS_TOKEN)) {
    /* has token */
    if (to.path === '/user/login') {
      next({ path: GlobalConstant.PC_INDEX_PATH })
      NProgress.done()
    } else {
      console.log('to.path=================' + to.path)
      console.log('to.path=================2' + store.getters.roles.length)
      if (store.getters.roles.length === 0) {
        store
          .dispatch('GetInfo')
          .then(res => {
            const menus = res.data.menuTrees
            store.dispatch('GenerateRoutes', { menus }).then(() => {
              // 根据roles权限生成可访问的路由表
              // 动态添加可访问路由表
              router.addRoutes(store.getters.addRouters)
              // 根据权限前往工作台
              let newPath = null
              if (to.path === '/toWorkplaceBacklog') {
                const role = res.data.roles.join()
                console.log('to.path=================3' + role)
                switch (true) {
                  case role.includes('repair'):
                    newPath = '/NewWorkplaceBacklog'
                    break
                  case role.includes('store'):
                    newPath = '/StoreWorkplaceBacklog'
                    break
                  default :
                    newPath = '/WorkplaceBacklog'
                    break
                }
              } else {
                newPath = to.path
              }
              const redirect = decodeURIComponent(from.query.redirect || newPath)

              if (newPath === redirect) {
                // hack方法 确保addRoutes已完成 ,set the replace: true so the navigation will not leave a history record
                next({ ...to, path: newPath, replace: true })
              } else {
                // 跳转到目的路由
                next({ path: redirect })
              }
            })
          })
          .catch(() => {
            notification.error({
              message: '错误',
              description: '请求用户信息失败，请重试'
            })
            store.dispatch('Logout').then(() => {
              next({ path: '/user/login', query: { redirect: to.fullPath } })
            })
          })
      } else {
        next()
      }
    }
  } else {
    if (whiteList.includes(to.name)) {
      // 在免登录白名单，直接进入
      next()
    } else {
      // next({ path: '/user/login', query: { redirect: to.fullPath } })
      next({ path: '/user/login', query: { } })
      NProgress.done() // if current page is login will not trigger afterEach hook, so manually handle it
    }
  }
})

router.afterEach(() => {
  NProgress.done() // finish progress bar
})
