// eslint-disable-next-line
import * as loginService from '@/api/upms/login'
// eslint-disable-next-line
import { UserLayout, BasicLayout, BlankLayout, RouteView, PageView } from '@/layouts'
import { GlobalConstant } from '@/constant'
import BaseTool from '../utils/tool'

// 前端路由表
const constantRouterComponents = {
  // 基础页面 layout 必须引入
  'UserLayout': UserLayout,
  'BasicLayout': BasicLayout,
  'BlankLayout': BlankLayout,
  'RouteView': RouteView,
  'PageView': PageView,
  '403': () => import(/* webpackChunkName: "error" */ '@/views/exception/403'),
  '404': () => import(/* webpackChunkName: "error" */ '@/views/exception/404'),
  '500': () => import(/* webpackChunkName: "error" */ '@/views/exception/500'),
  'IndexView': () => import(/* webpackChunkName: "error" */ '@/views/index/Index'),
  // upms
  'Dept': () => import('@/views/upms/dept/Dept'),
  'User': () => import('@/views/upms/user/User'),
  'Role': () => import('@/views/upms/role/Role'),
  'Menu': () => import('@/views/upms/menu/Menu'),
  'Dict': () => import('@/views/upms/dict/Dict'),
  'Notice': () => import('@/views/upms/notice/SysNotice'),
  'Log': () => import('@/views/upms/log/Log'),
  'Task': () => import('@/views/upms/task/Task'),
  'Config': () => import('@/views/upms/config/Config'),
  'SysTeam': () => import('@/views/upms/team/SysTeam'),

  // result
  'ResultSuccess': () => import(/* webpackChunkName: "result" */ '@/views/result/Success'),
  'ResultFail': () => import(/* webpackChunkName: "result" */ '@/views/result/Error'),

  // exception
  'Exception403': () => import(/* webpackChunkName: "fail" */ '@/views/exception/403'),
  'Exception404': () => import(/* webpackChunkName: "fail" */ '@/views/exception/404'),
  'Exception500': () => import(/* webpackChunkName: "fail" */ '@/views/exception/500'),

  // account
  'AccountCenter': () => import('@/views/account/center/Index'),
  'AccountSettings': () => import('@/views/account/settings/Index'),
  // 其他组件
  'SystemRoleList': () => import('@/views/role/RoleList'),
  // 设备类型
  'SbType': () => import('@/views/sb/type/SbType'),
  // 项目类型
  'Project': () => import('@/views/project/Project'),
  // 设备位置
  'SbPosition': () => import('@/views/sb/position/SbPosition'),
  // 设备位置台账
  'SbPositionCount': () => import('@/views/sb/count/SbPositionCount'),
  'SbPositionNum': () => import('@/views/sb/position/SbPositionNum'),
  // 设备状态台账
  'SbStatusCount': () => import('@/views/sb/count/SbStatusCount'),
  // 设备自定义类型台账
  'SbUseTypeCount': () => import('@/views/sb/count/SbUseTypeCount'),
  // 设别规格
  'SbGuige': () => import('@/views/sb/guige/SbGuige'),
  // 设别基础信息
  'SbInfo': () => import('@/views/sb/info/SbInfo'),
  // 测量设备基础信息
  'MeasureSbInfo': () => import('@/views/sb/info/MeasureSbInfo'),
  'MeasureSbInfoAll': () => import('@/views/sb/info/MeasureSbInfoAll'),
  // 测量设备基础信息-需要检定-外部检定的
  'MeasureSbInfoCheck': () => import('@/views/sb/info/MeasureSbInfoCheck'),
  // 测量设备基础信息-需要检定-自检的
  'MeasureSbInfoCheckSelf': () => import('@/views/sb/info/MeasureSbInfoCheckSelf'),
  // 测量设备基础信息-不需要检定的
  'MeasureSbInfoNotCheck': () => import('@/views/sb/info/MeasureSbInfoNotCheck'),
  // 测量设备预警台账
  'MeasureSbInfoWarn': () => import('@/views/sb/info/MeasureSbInfoWarn'),
  // 测量设备基础信息-在库
  'MeasureSbInfoInStore': () => import('@/views/sb/info/MeasureSbInfoInStore'),
  // 测量设备-检定记录
  'MeasureLog': () => import('@/views/sb/measurelog/MeasureLog'),
  // 特种设备-检定记录
  'MeasureLogSpecial': () => import('@/views/sb/measurelog/MeasureLogSpecial'),
  // 特种设备基础信息
  'SpecialSbInfo': () => import('@/views/sb/info/SpecialSbInfo'),
  'SpecialSbInfo2': () => import('@/views/sb/info/SpecialSbInfo2'),

  // 特种设备预警
  'SpecialSbInfoWarn': () => import('@/views/sb/info/SpecialSbInfoWarn'),
  // 特种设备在库
  'SpecialSbInfoInStore': () => import('@/views/sb/info/SpecialSbInfoInStore'),
  // 父子设备树
  'ParentSbInfo': () => import('@/views/sb/info/ParentSbInfo'),
  // 设别型号库
  'SbModel': () => import('@/views/sb/model/SbModel'),
  // 设备bom
  'SbModelBom': () => import('@/views/sb/modelbom/SbModelBom'),
  // 设备型号筛选对应的备件bom
  'SbModelSpareListBom': () => import('@/views/sb/modelbom/SbModelSpareListBom'),
  // 设备树
  'SbInfoTree': () => import('@/views/sb/info/SbInfoTree'),
  // 部位类别
  'PartType': () => import('@/views/part/type/PartType'),
  // 部位信息
  'PartInfo': () => import('@/views/part/info/PartInfo'),
  // 设备部位信息
  'SbInfoForPartInfo': () => import('@/views/sb/info/SbInfoForPartInfo'),
  // 位号信息
  'Location': () => import('@/views/sb/location/Location'),
  // 设备位号信息
  'SbInfoForLocation': () => import('@/views/sb/info/SbInfoForLocation'),
  // 设备履历
  'SbResume': () => import('@/views/sb/resume/SbResume'),
  'PositionNoResume': () => import('@/views/sb/resume/PositionNoResume'),
  // 备件类别
  'SpareType': () => import('@/views/sqarepartmanage/sparetype/SpareType'),
  // 备件基础信息和报表
  'SparePartInfo': () => import('@/views/sqarepartmanage/sparepartinfo/SparePartInfo'),
  'SparePartInfoPrint': () => import('@/views/sqarepartmanage/sparepartinfo/SparePartInfoPrint'),
  'SparePartMonthReport': () => import('@/views/sqarepartmanage/report/SparePartMonthReport'),
  // 备件库存汇总、备件库存汇总预警、备件保养预警（已废弃，改成备件更换预警）
  'SparePartTotal': () => import('@/views/sqarepartmanage/sparepartinfo/SparePartTotal'),
  'SparePartTotalMinStock': () => import('@/views/sqarepartmanage/sparepartinfo/SparePartTotalMinStock'),
  'SparePartTotalCheckStock': () => import('@/views/sqarepartmanage/sparepartinfo/SparePartTotalCheckStock'),
  'SpareUpdateAlert': () => import('@/views/sqarepartmanage/sparepartinfo/SpareUpdateAlert'),

  // 仓库汇总、仓库备件库存汇总（单个仓库的）
  'SpareStoreTotal': () => import('@/views/store/sparestore/SpareStoreTotal'),
  'SpareStoreTotalMinStock': () => import('@/views/store/sparestore/SpareStoreTotalMinStock'),

  // 备件使用信息
  'SparePartUsed': () => import('@/views/sqarepartmanage/sparepartused/SparePartUsed'),
  'SbInfoStopDetail': () => import('@/views/sb/stop-detail/SbInfoStopDetail'),
  // 点检
  'SpotCheckStandard': () => import('@/views/check/checkstandard/SpotCheckStandard'),
  'SpotCheckProject': () => import('@/views/check/checkproject/SpotCheckProject'),
  'SpotCheckPlan': () => import('@/views/check/checkplan/SpotCheckPlan'),
  'SpotCheckJobOverTime': () => import('@/views/check/checkjob/SpotCheckJobOverTime'),
  'SpotCheckJob': () => import('@/views/check/checkjob/SpotCheckJob'),
  'SpotCheckJobFinish': () => import('@/views/check/checkjob/SpotCheckJobFinish'),
  // 保养
  'PollingCheckStandard': () => import('@/views/check/checkstandard/PollingCheckStandard'),
  'PollingCheckProject': () => import('@/views/check/checkproject/PollingCheckProject'),
  'PollingCheckPlan': () => import('@/views/check/checkplan/PollingCheckPlan'),
  'PollingCheckJob': () => import('@/views/check/checkjob/PollingCheckJob'),
  'PollingCheckJobOverTime': () => import('@/views/check/checkjob/PollingCheckJobOverTime'),
  'PollingCheckJobFinish': () => import('@/views/check/checkjob/PollingCheckJobFinish'),
  // 润滑
  'RunCheckStandard': () => import('@/views/check/checkstandard/RunCheckStandard'),
  'RunCheckProject': () => import('@/views/check/checkproject/RunCheckProject'),
  'RunCheckPlan': () => import('@/views/check/checkplan/RunCheckPlan'),
  'RunCheckJob': () => import('@/views/check/checkjob/RunCheckJob'),
  'RunCheckJobOverTime': () => import('@/views/check/checkjob/RunCheckJobOverTime'),
  'RunCheckJobFinish': () => import('@/views/check/checkjob/RunCheckJobFinish'),
  // 工器具校准
  'AdjustCheckStandard': () => import('@/views/check/checkstandard/AdjustCheckStandard'),
  'AdjustCheckProject': () => import('@/views/check/checkproject/AdjustCheckProject'),
  'AdjustCheckPlan': () => import('@/views/check/checkplan/AdjustCheckPlan'),
  'AdjustCheckJob': () => import('@/views/check/checkjob/AdjustCheckJob'),
  // 特种设备定期检验
  'SpecialCheckStandard': () => import('@/views/check/checkstandard/SpecialCheckStandard'),
  'SpecialCheckProject': () => import('@/views/check/checkproject/SpecialCheckProject'),
  'SpecialCheckPlan': () => import('@/views/check/checkplan/SpecialCheckPlan'),
  'SpecialCheckJob': () => import('@/views/check/checkjob/SpecialCheckJob'),
  // 仓库信息
  'Store': () => import('@/views/store/store/Store'),
  // 备件库存
  'SpareStore': () => import('@/views/store/sparestore/SpareStore'),
  'PurchaseStoreForm': () => import('@/views/store/purchaseform/PurchaseStoreForm'),
  // 备件二级库存
  'SpareStoreSecond': () => import('@/views/store/sparestoresecond/SpareStoreSecond'),
  // 入库登记单
  'InStoreForm': () => import('@/views/store/instoreform/InStoreForm'),
  // 出库登记单
  'OutStoreForm': () => import('@/views/store/outstoreform/OutStoreForm'), // 出库
  'OutStoreFormYY': () => import('@/views/store/outstoreform/OutStoreFormYY'), // 用友出库
  'OutStoreFormBackYY': () => import('@/views/store/outstoreform/OutStoreFormBackYY'), // 用友退库
  // 调拨登记单
  'TransferStoreForm': () => import('@/views/store/transferstoreform/TransferStoreForm'),

  // 备件领用详情
  'SparePickDetail': () => import('@/views/store/sparepickdetail/SparePickDetail'),
  // 备件领用登记单
  'SparePickForm': () => import('@/views/store/sparepickform/SparePickForm'),
  // 备件回收详情
  'SpareRecoveryDetail': () => import('@/views/store/sparerecoverydetail/SpareRecoveryDetail'),
  // 备件回收登记单
  'SpareRecoveryForm': () => import('@/views/store/sparerecoveryform/SpareRecoveryForm'),
  // 备件退库详情
  'SpareRestoreDetail': () => import('@/views/store/sparerestoredetail/SpareRestoreDetail'),
  // 备件退库登记单
  'SpareRestoreForm': () => import('@/views/store/sparerestoreform/SpareRestoreForm'),
  // 备件退货详情
  'SpareBackDetail': () => import('@/views/store/sparebackdetail/SpareBackDetail'),
  // 备件退货登记单
  'SpareBackForm': () => import('@/views/store/sparebackform/SpareBackForm'),
  // 入库详情
  'InStoreDetail': () => import('@/views/store/instoredetail/InStoreDetail'),
  // 出库详情
  'OutStoreDetail': () => import('@/views/store/outstoredetail/OutStoreDetail'),
  // 调拨详情
  'TransferStoreDetail': () => import('@/views/store/transferstoredetail/TransferStoreDetail'),
  // 报修单
  'RepairApplicationForm': () => import('@/views/repair/application-form/RepairApplicationForm'),

  'RepairOut': () => import('@/views/repair/application-form/RepairOut'),
  // 验收单
  'RepairCheckForm': () => import('@/views/repair/application-form/RepairCheckForm'),
  // 维修单
  'RepairForm': () => import('@/views/repair/application-form/RepairForm'),
  'Calendars': () => import('@/views/repair/calendar/Calendar'),
  'AgainRepairForm': () => import('@/views/repair/application-form/AgainRepairForm'),
  'RepairCloseForm': () => import('@/views/repair/application-form/RepairCloseForm'),
  'MRepairForm': () => import('@/views/repair/application-form/MyRepairForm'),
  'MyRepairForm': () => import('@/views/repair/form/MyRepairForm'),
  'WaitRepairForm': () => import('@/views/repair/application-form/WaitRepairForm'),
  'RepairCallerCheckForm': () => import('@/views/repair/application-form/RepairCallerCheckForm'),
  'RepairManagerCheckForm': () => import('@/views/repair/application-form/RepairManagerCheckForm'),
  'WaitAllocatedRepairForm': () => import('@/views/repair/application-form/WaitAllocatedRepairForm'),
  'WaitDispatchRepairForm': () => import('@/views/repair/application-form/WaitDispatchRepairForm'),
  'ReportRepairForm': () => import('@/views/repair/application-form/ReportRepairForm'),
  'RepairFormPool': () => import('@/views/repair/application-form/RepairFormPool'),
  // 验收单
  'RepairCheck': () => import('@/views/repair/check/RepairCheck'),
  // 故障类别
  'ErrorType': () => import('@/views/repair/errortype/ErrorType'),
  // 维修费用单
  'RepairFee': () => import('@/views/repair/fee/RepairFee'),
  // 维修项目
  'RepairProject': () => import('@/views/repair/repairproject/RepairProject'),
  'RepairReason': () => import('@/views/repair/repair-reason/RepairReason'),
  // 生产商
  'FirmProducer': () => import('@/views/firm/producer/FirmProducer'),
  // 巡检管理
  'FillInfo': () => import('@/views/fill/info/FillInfo'),
  'FillGather': () => import('@/views/fill/gather/FillGather'),
  'FillGatherTask': () => import('@/views/fill/task/FillGatherTask'),
  'BackFillGatherTask': () => import('@/views/fill/task/BackFillGatherTask'),
  'VerifyFillGatherTask': () => import('@/views/fill/task/VerifyFillGatherTask'),
  'SbInspectionFill': () => import('@/views/sb/inspection-fill/SbInspectionFill'),
  'MySbInspectionFill': () => import('@/views/sb/inspection-fill/MySbInspectionFill'),
  'ZGSbInspectionFill': () => import('@/views/sb/inspection-fill/ZGSbInspectionFill'),
  'AdminSbInspectionFill': () => import('@/views/sb/inspection-fill/AdminSbInspectionFill'),
  'SbRunFill': () => import('@/views/sb/run-fill/SbRunFill'),
  'ZGSbRunFill': () => import('@/views/sb/run-fill/ZGSbRunFill'),
  'MySbRunFill': () => import('@/views/sb/run-fill/MySbRunFill'),
  'AdminSbRunFill': () => import('@/views/sb/run-fill/AdminSbRunFill'),
  // 仓库月报表
  'StoreMonthReport': () => import('@/views/report/store/StoreMonthReport'),
  // 出入库明细+汇总
  'ReportInStoreDetail': () => import('@/views/report/instoredetail/InStoreDetail'),
  'MyReportInStoreDetail': () => import('@/views/report/instoredetail/MyInStoreDetail'),
  'ReportOutStoreDetail': () => import('@/views/report/outstoredetail/OutStoreDetail'),
  'MyReportOutStoreDetail': () => import('@/views/report/outstoredetail/MyOutStoreDetail'),
  'ReportInStoreCount': () => import('@/views/report/instorecount/InStoreCount'),
  'ReportOutStoreCount': () => import('@/views/report/outstorecount/OutStoreCount'),
  'ReportSparePartInfo': () => import('@/views/report/sparepartinfo/SparePartInfo'),
  'ReportSparePickDetail': () => import('@/views/report/sparepickdetail/SparePickDetail'),
  'MyReportSparePickDetail': () => import('@/views/report/sparepickdetail/MySparePickDetail'),
  'ReportSparePickCount': () => import('@/views/report/sparepickcount/SparePickCount'),
  'StatisticsRepairFormSb': () => import('@/views/statistics/repair/StatisticsRepairFormSb'),
  'StatisticsRepairFormMonth': () => import('@/views/statistics/repair/StatisticsRepairFormMonthView'),
  'StatisticsRepairFormErrorType': () => import('@/views/statistics/repair/StatisticsRepairFormErrorTypeView'),
  'StatisticsSparePartUsedSpare': () => import('@/views/statistics/spare/StatisticsSparePartUsedSpare'),
  'StatisticsRepairFormUser': () => import('@/views/statistics/repair/StatisticsRepairFormUserView'),
  'WorkplaceBacklog': () => import('@/views/workplace/backlog/WorkplaceBacklog'),
  'Workbench': () => import('@/views/workplace/backlog/Workbench'),
  'StoreWorkplaceBacklog': () => import('@/views/workplace/backlog/StoreWorkplaceBacklog'),
  'SbWorkplaceBacklog': () => import('@/views/workplace/backlog/SbWorkplaceBacklog'),
  'NewWorkplaceBacklog': () => import('@/views/workplace/backlog/NewWorkplaceBacklog'),
  'Supplier': () => import('@/views/purchase/supplier/Supplier'),
  'SupplierApply': () => import('@/views/purchase/supplier/SupplierApply'),
  'PurchaseDemandPlan': () => import('@/views/purchase/purchase-demand-plan/PurchaseDemandPlan'),
  'PurchasePlan': () => import('@/views/purchase/purchase-plan/PurchasePlan'),
  'PurchasePayment': () => import('@/views/purchase/purchase-payment/PurchasePaymentPage'),
  'PurchaseReimburse': () => import('@/views/purchase/purchase-reimburse/PurchaseReimbursePage'),
  'PurchaseOrder': () => import('@/views/purchase/purchase-order/PurchaseOrder'),
  'PurchaseApply': () => import('@/views/purchase/purchase-apply/PurchaseApply'),
  'PurchaseDispatchOrderPage': () => import('@/views/purchase/purchase-dispatch-order/PurchaseDispatchOrderPage'),
  // 审批
  'Model': () => import('@/views/activiti/model/Model'),
  'Flow': () => import('@/views/activiti/flow/Flow'),
  'MyTask': () => import('@/views/activiti/task/MyTask'), // 我的待办
  'MyTaskFinish': () => import('@/views/activiti/task/MyTaskFinish'), // 我的已办
  'MyTaskClaim': () => import('@/views/activiti/task/MyTaskClaim'), // 我的签收
  'MyStart': () => import('@/views/activiti/task/MyStart'), // 我的申请
  'ActivitiUserModel': () => import('@/views/activiti/user-model/ActivitiUserModel'), // 流程审批节点设置
  'DesignForm': () => import('@/views/design/designForm/DesignForm'),
  // 隐患管理
  'HiddenDangerWait': () => import('@/views/hidden/hidden/HiddenDangerWait'), // 隐患任务
  'HiddenDangerHandle': () => import('@/views/hidden/hidden/HiddenDangerHandle'), // 隐患任务
  // 调拨申请
  'SbAllocateApply': () => import('@/views/sb/allocate-apply/ProjectSbAllocateApply'),
  'GroupToProjectSbAllocateApply': () => import('@/views/sb/allocate-apply/GroupToProjectSbAllocateApply'),
  'ProjectToProjectSbAllocateApply': () => import('@/views/sb/allocate-apply/ProjectToProjectSbAllocateApply'),
  'MySbAllocateApply': () => import('@/views/sb/allocate-apply/MySbAllocateApply'),
  'ZGSbAllocateApply': () => import('@/views/sb/allocate-apply/ZGSbAllocateApply'),
  'XmbZgSbAllocateApply': () => import('@/views/sb/allocate-apply/XmbZgSbAllocateApply'),
  'FgsZgSbAllocateApply': () => import('@/views/sb/allocate-apply/FgsZgSbAllocateApply'),
  // 调拨审批
  'SbAllocateTaskAudit': () => import('@/views/sb/allocate-task/SbAllocateTaskAudit'),
  // 我的功能
  'ProjectStore': () => import('@/views/store/store/ProjectStore'),
  'CompanyStore': () => import('@/views/store/store/CompanyStore'),
  'MyStore': () => import('@/views/store/store/MyStore'),
  'MyInStoreForm': () => import('@/views/store/instoreform/MyInStoreForm'),
  'MyOutStoreForm': () => import('@/views/store/outstoreform/MyOutStoreForm'),
  'MyTransferStoreForm': () => import('@/views/store/transferstoreform/MyTransferStoreForm'),
  'MySparePickForm': () => import('@/views/store/sparepickform/MySparePickForm'),
  'MySbInfo': () => import('@/views/sb/info/MySbInfo'),
  'ProjectSbInfo': () => import('@/views/sb/info/ProjectSbInfo'),
  'BanzuSbInfo': () => import('@/views/sb/info/BanzuSbInfo'),
  'CompanySbInfo': () => import('@/views/sb/info/CompanySbInfo'),
  'MySpareStore': () => import('@/views/store/sparestore/MySpareStore'),
  'MySpareStoreTotal': () => import('@/views/store/sparestore/MySpareStoreTotal'),
  'MyRunCheckJob': () => import('@/views/check/checkjob/MyRunCheckJob'),
  'MyPollingCheckJob': () => import('@/views/check/checkjob/MyPollingCheckJob'),
  'MyPollingCheckJobFinish': () => import('@/views/check/checkjob/MyPollingCheckJobFinish'),
  'MyPollingCheckJobOverTime': () => import('@/views/check/checkjob/MyPollingCheckJobOverTime'),
  'MySpotCheckJob': () => import('@/views/check/checkjob/MySpotCheckJob'),
  // 验收单
  'SbCheckForm': () => import('@/views/sb/sbcheckform/SbCheckForm'),
  'FillProjectQuantity': () => import('@/views/fill/project-quantity/FillProjectQuantity'),
  'SbCheckDetail': () => import('@/views/sb/sbcheckdetail/SbCheckDetail'),
  // 资料管理
  'Article': () => import('@/views/operate/article/Article'),
  'CustomerInfo': () => import('@/views/operate/customer/CustomerInfo'),

  // 设备变动
  'SbScrapForm': () => import('@/views/sb/scraps/SbScrapForm'), // 报废单
  // 设备变动记录
  'SbChangeRecord': () => import('@/views/sb/change-record/SbChangeRecord'), // 设备变动记录
  // 备件盘点
  'StoreCheckPlan': () => import('@/views/store/storecheckplan/StoreCheckPlan'),
  'StoreCheckJob': () => import('@/views/store/storecheckjob/StoreCheckJob'),

  // 设备盘点
  'SbStoreCheckPlan': () => import('@/views/sb/storecheckplan/StoreCheckPlan'),
  'SbStoreCheckJob': () => import('@/views/sb/storecheckjob/StoreCheckJob'),
  // 保养任务日程表
  'CheckJobCalendar': () => import('@/views/check/checkjob/CheckJobCalendar'),
  // 设备状态变更表
  'SbStatusLog': () => import('@/views/sb/status-log/SbStatusLog'),
  // 设备停机记录表
  'SbStopLog': () => import('@/views/sb/stop-logs/SbStopLog'),

  // 设备安装调试过程记录
  'SbInfoDebug': () => import('@/views/sb/info/SbInfoDebug'),
  // 设备试车过程记录
  'SbInfoTestRun': () => import('@/views/sb/info/SbInfoTestRun'),

  // 设备报废
  'SbInfoScrap': () => import('@/views/sb/scrap/SbInfoScrap'),
  // 设备维护标准
  'SbInfoStandard': () => import('@/views/sb/info/SbInfoStandard'),

  // 报表
  'RepairDetail': () => import('@/views/report/repairdetail/RepairDetail'), // 维修报表
  'AnalysisSbInfo': () => import('@/views/dashboard/AnalysisSbInfo'), // 保养任务完成率报表
  'CheckJobReport': () => import('@/views/dashboard/CheckJobReport'), // 保养任务完成率报表
  'MeasureLogReport': () => import('@/views/dashboard/MeasureLogReport'), // 检定记录月完成数量报表
  'SbInfoTypeReport': () => import('@/views/dashboard/SbInfoTypeReport'), // 设备类型占比统计
  'CheckJobReportWeek': () => import('@/views/dashboard/CheckJobReportWeek'), // 保养任务周工作负荷统计报表
  'RepairReport': () => import('@/views/dashboard/RepairReport'), // >24小时停机次数按月统计
  'RepairReportSbAll': () => import('@/views/dashboard/RepairReportSbAll'), // 设备故障次数按月统计
  'RepairReportSbInfo': () => import('@/views/dashboard/RepairReportSbInfo'), // 设备维修报表
  'RepairReportSbInfoFee': () => import('@/views/dashboard/RepairReportSbInfoFee'), // 设备维修费用报表
  'RepairReportMttr': () => import('@/views/dashboard/RepairReportMttr'), // MTTR月统计报表
  'RepairReportFee': () => import('@/views/dashboard/RepairReportFee'), // 费用按月统计
  'StoreReport1': () => import('@/views/dashboard/StoreReport1'), // 仓库报表
  'FillGatherReport': () => import('@/views/dashboard/FillGatherReport'), // 巡检任务月统计
  'RepairReportFail': () => import('@/views/dashboard/RepairReportFail'), // 设备故障排行榜统计

  'RepairScreen': () => import('@/views/big-screen/RepairScreen'), // 车间大屏
  // 工作台
  'SbInfoWorkplaceBacklog': () => import('@/views/workplace/backlog/SbInfoWorkplaceBacklog'), // 设备工作台
  // 自定义管理
  'CustomizeReport': () => import('@/views/customize/report/CustomizeReport'), // 自定义报表
  'CustomFieldTemplate': () => import('@/views/customize/fieldTemplate/CustomFieldTemplate'), // 自定义模板
  'CustomFieldTemplateData': () => import('@/views/customize/fieldTemplateData/CustomFieldTemplateData'), // 自定义模板数据
  // 新增路由
  'SparePartUsedSelectTable': () => import('@/views/sqarepartmanage/sparepartused/modules/SparePartUsedSelectTable'), // 备件使用记录
  // 电度和遥测数据
  'RemoteMeasure': () => import('@/views/remote/measure/RemoteMeasure'),
  'RemoteMeasureLog': () => import('@/views/remote/measure-log/RemoteMeasureLog'),
  'RemoteDegree': () => import('@/views/remote/degree/RemoteDegree'),
  'RemoteDegreeLog': () => import('@/views/remote/degree-log/RemoteDegreeLog'),
  // opc
  'RemoteOpc': () => import('@/views/remote/opc/RemoteOpc'), // 模拟+数字量+创建+未创建（全部的）
  'RemoteOpcNotCreated': () => import('@/views/remote/opc/RemoteOpcNotCreated'), // 服务端未创建对应的点位
  'RemoteOpcLog': () => import('@/views/remote/opc-log/RemoteOpcLog'), // 记录
  'OpcPosition': () => import('@/views/remote/opc/OpcPosition'), // opc车间
  'OpcPositionNot': () => import('@/views/remote/opc/OpcPositionNot'), // opc车间未配置
  'OpcPositionForProducer': () => import('@/views/remote/opc/OpcPositionForProducer'), // opc车间生产入口
  'RemotePosition': () => import('@/views/remote/position/RemotePosition'), // opc车间配置
  // 初始化导入
  'ImportExcel': () => import('@/views/excel/ImportExcel'),

  // 乾坤
  'Plan': () => import('@/views/qykh/plan/Plan'),
  'PlanDetail': () => import('@/views/qykh/plan-detail/PlanDetail'),
  'Product': () => import('@/views/qykh/product/Product'),
  'ProductHelp': () => import('@/views/qykh/product-help/ProductHelp'),
  'Hotspot': () => import('@/views/qykh/hotspot/Hotspot'),
  'HotspotHelp': () => import('@/views/qykh/hotspot-help/HotspotHelp'),
  'Information': () => import('@/views/qykh/information/Information'),
  'InformationHelp': () => import('@/views/qykh/information-help/InformationHelp'),
  // 筹建管理
  'PreparationAll': () => import('@/views/preparation/preparation/PreparationAll'),
  'PreparationMine': () => import('@/views/preparation/preparation/PreparationMine'),
  'PreparationVerify': () => import('@/views/preparation/preparation/PreparationVerify'),
  'PreparationReceive': () => import('@/views/preparation/preparation/PreparationReceive'),
  'PreparationReport': () => import('@/views/preparation/report/PreparationReport'),
  'PreparationReportPie': () => import('@/views/preparation/report/PreparationReportPie'),
  'PreparationsPosition': () => import('@/views/preparation/report/PreparationsPosition'),
  'Building': () => import('@/views/preparation/preparation/Building'),
  // 防雷检测
  'Light': () => import('@/views/light/light/Light'),
  'LightWaitCheck': () => import('@/views/light/light/LightWaitCheck'),
  'LightLog': () => import('@/views/light/light-log/LightLog'),
  // 工器具管理
  'Tool': () => import('@/views/tool/tool/Tool'),
  'ToolWaitCheck': () => import('@/views/tool/tool/ToolWaitCheck'),
  'ToolLog': () => import('@/views/tool/tool-log/ToolLog'),
  // 日历
  'Calendar': () => import('@/views/calendar/Calendar'),
  // 采购
  'PurchaseOrderPage': () => import('@/views/purchase/purchase-order-page/PurchaseOrderPage'),
  'PurchaseOrderRecord': () => import('@/views/purchase/purchase-order-record/PurchaseOrderRecord'),
  'PurchaseOrderReport': () => import('@/views/purchase/purchase-order-report/PurchaseOrderReport'),
  'PurchaseOrderReportByTime': () => import('@/views/purchase/purchase-order-report/PurchaseOrderReportByTime'),
  'PurchaseOrderReportByFifity': () => import('@/views/purchase/purchase-order-report/PurchaseOrderReportByFifity'),
  'Inventory': () => import('@/views/purchase/inventory/Inventory.vue'),
  'InventoryList': () => import('@/views/purchase/inventory-list/InventoryList.vue'),
  'PurchaseOrderReportPie': () => import('@/views/purchase/purchase-order-report/PurchaseOrderReportPie.vue'),
  // 资产闲置
  'IdleAssets': () => import('@/views/idle-assets/IdleAssets.vue')
}

// 前端未找到页面路由（固定不用改）
const notFoundRouter = {
  path: '*', redirect: '/404', hidden: true
}

// 根级菜单
const rootRouter = {
  key: 'RootIndex',
  path: '/',
  url: '/',
  name: 'index',
  component: 'BasicLayout',
  meta: { title: '首页' },
  redirect: '/WorkplaceBacklog',
  type: 1,
  children: []
}

/**
 * 基础路由
 * @type { *[] }
 */
export const constantRouterMap = [
  {
    path: '/user',
    component: UserLayout,
    redirect: '/user/login',
    hidden: true,
    children: [
      {
        path: 'login',
        name: 'login',
        component: () => import(/* webpackChunkName: "user" */ '@/views/Login')
      },
      {
        path: '/work/scan',
        name: 'scan',
        component: () => import(/* webpackChunkName: "user" */ '@/views/Scan')
      },
      {
        path: 'register',
        name: 'register',
        component: () => import(/* webpackChunkName: "user" */ '@/views/Register')
      },
      {
        path: 'register-result',
        name: 'registerResult',
        component: () => import(/* webpackChunkName: "user" */ '@/views/RegisterResult')
      },
      {
        path: 'recover',
        name: 'recover',
        component: undefined
      }
    ]
  },
  {
    path: '/404',
    component: () => import(/* webpackChunkName: "fail" */ '@/views/exception/404')
  },
  {
    path: '/tree',
    component: () => import('@/views/sb/info/modules/SbTreeModal.vue')
  },
  {
    path: '/opc',
    component: () => import('@/views/opc/Opc.vue')
  },
  {
    path: '/opc/info',
    component: () => import('@/views/opc/OpcInfo.vue')
  },
  {
    path: '/toWorkplaceBacklog',
    component: () => import('@/views/statisticView/22')
  },
  {
    path: '/InfoBigScreen',
    component: () => import('@/views/statisticView/22')
  },
  {
    path: '/InfoDetailBigScreen',
    component: () => import('@/views/statisticView/44')
  },
  {
    path: '/RepairBigScreen',
    component: () => import('@/views/statisticView/100')
  },
  {
    path: '/SwitchingRoomBigScreen',
    component: () => import('@/views/statisticView/SwitchingRoom')
  },
  {
    path: '/TransformerDetailBigScreen',
    component: () => import('@/views/statisticView/TransformerDetail')
  },
  {
    path: '/TransformerHistoryBigScreen',
    component: () => import('@/views/statisticView/TransformerHistory')
  },
  {
    path: '/DayStatistics',
    component: () => import('@/views/statisticView/DayStatistics')
  },
  {
    path: '/MonthStatistics',
    component: () => import('@/views/statisticView/MonthStatistics')
  },
  {
    path: '/StoreBigScreen',
    component: () => import('@/views/statisticView/9')
  },
  {
    path: '/main',
    component: () => import('@/views/statisticView/Main')
  },
  {
    path: '/platformSystem',
    component: () => import('@/views/statisticView/PlatformSystem')
  },
  {
    path: '/single/login',
    name: 'SingleLogin',
    component: () => import('@/views/white-list/SingleLogin'),
    meta: {
      title: '单点登录',
      keepAlive: false,
      hiddenHeaderContent: true,
      target: null,
      permission: ''
    },
    hidden: true,
    hideChildrenInMenu: true
  },
  {
    path: '/result/success',
    name: 'ResultSuccess',
    component: () => import(/* webpackChunkName: "result" */ '@/views/result/Success'),
    meta: {
      title: '结果页',
      keepAlive: false,
      hiddenHeaderContent: true,
      target: null,
      permission: ''
    },
    hidden: true,
    hideChildrenInMenu: true

  }

]

/**
 * 默认菜单
 */
const defaultRouter = {
  key: 'RootDefault',
  path: '/default',
  url: '/default',
  name: 'default',
  component: BasicLayout,
  meta: { title: '默认' },
  redirect: '/account/settings',
  type: 1,
  children: [
    {
      path: '/account/center',
      name: 'center',
      component: constantRouterComponents['AccountCenter'],
      meta: {
        title: '个人中心',
        keepAlive: false,
        hiddenHeaderContent: false,
        target: null,
        permission: ''
      },
      hidden: true,
      hideChildrenInMenu: true
    },
    {
      path: '/account/settings',
      name: 'settings',
      component: constantRouterComponents['AccountSettings'],
      meta: {
        title: '个人设置',
        keepAlive: false,
        hiddenHeaderContent: true,
        target: null,
        permission: ''
      },
      hidden: true,
      hideChildrenInMenu: true
    }]
}

/**
 * 动态生成菜单
 * @param token
 * @returns {Promise<Router>}
 */
export const generatorDynamicRouter = (menus) => {
  return new Promise((resolve, reject) => {
    try {
      const menuNav = []
      //      后端数据, 根级树数组,  根级 PID,后端已转为树型 解构
      // listToTree(result, childrenNav, 0)
      rootRouter.children = menus
      menuNav.push(rootRouter)
      const routers = generator(menuNav)
      routers.push(notFoundRouter)
      routers.push(defaultRouter)
      resolve(routers)
    } catch (e) {
      reject(e)
    }
  })
}

/**
 * 格式化树形结构数据 生成 vue-router 层级路由表
 *
 * @param routerMap
 * @param parent
 * @returns {*}
 */
export const generator = (routerMap, parent) => {
  return routerMap.map(itemTree => {
    let item = itemTree.item
    if (BaseTool.Object.isBlank(item)) {
      item = itemTree
    }
    item.children = itemTree.children
    // 如果不是菜单则跳过
    if (GlobalConstant.MenuTypeMenu === item.type) {
      return null
    }
    // path: '/dashboard',
    //         name: 'dashboard',
    //         redirect: '/dashboard/workplace', // 可以做父路由到子路由的跳转
    //         component: RouteView,
    //         meta: { title: '仪表盘', keepAlive: true, icon: bxAnaalyse, permission: [ 'dashboard' ] },
    const { title, visible, hideChildren, hiddenHeaderContent, target, icon } = item || {}
    const myComponent = constantRouterComponents[item.component || item.name]
    const currentRouter = {
      // 如果路由设置了 path，则作为默认 path，否则 路由地址 动态拼接生成如 /dashboard/workplace
      path: item.url || `${parent && parent.url || ''}/${item.name}`,
      // 路由名称，建议唯一
      name: item.name,
      // 该路由对应页面的 组件 :方案1
      component: myComponent,
      // 该路由对应页面的 组件 :方案2 (动态加载)
      // component: constantRouterComponents[item.component || item.key] || () => import(`@/views/${item.component}`),

      // meta: 页面标题, 菜单图标, 页面权限(供指令权限用，可去掉)
      meta: { title: title, icon: icon || undefined, keepAlive: false, hiddenHeaderContent: hiddenHeaderContent || false, target: target, permission: item.permission }
    }
    // 是否设置了隐藏菜单
    if (visible === false) {
      currentRouter.hidden = true
    }
    // 是否设置了隐藏子菜单
    if (hideChildren || visible === false) {
      currentRouter.hideChildrenInMenu = true
    }
    // 为了防止出现后端返回结果不规范，处理有可能出现拼接出两个 反斜杠
    if (!currentRouter.path.startsWith('http')) {
      currentRouter.path = currentRouter.path.replace('//', '/')
    }
    // 重定向
    item.redirect && (currentRouter.redirect = item.redirect)
    // 是否有子菜单，并递归处理
    if (item.children && item.children.length > 0) {
      // Recursion
      currentRouter.children = generator(item.children, currentRouter)
    }
    return currentRouter
  })
}

/**
 * 数组转树形结构
 * @param list 源数组
 * @param tree 树
 * @param parentId 父ID
 */
// const listToTree = (list, tree, parentId) => {
//   list.forEach(item => {
//     // 判断是否为父级菜单
//     if (item.parentId === parentId) {
//       const child = {
//         ...item,
//         key: item.key || item.name,
//         children: []
//       }
//       // 迭代 list， 找到当前菜单相符合的所有子菜单
//       listToTree(list, child.children, item.id)
//       // 删掉不存在 children 值的属性
//       if (child.children.length <= 0) {
//         delete child.children
//       }
//       // 加入到树中
//       tree.push(child)
//     }
//   })
// }
